@@ -105,6 +105,9 @@ def stop() -> None:
 class Scalene:
     """The Scalene profiler itself."""
 
+    __in_jupyter = False # are we running inside a Jupyter notebook
+    __start_time = 0 # start of profiling, in nanoseconds
+    
     # Whether the current profiler is a child
     __is_child = -1
     # the pid of the primary profiler
@@ -189,6 +192,10 @@ class Scalene:
     __memcpy_sigq: ScaleneSigQueue[Any]
     __sigqueues: List[ScaleneSigQueue[Any]]
 
+    @staticmethod
+    def set_jupyter():
+        Scalene.__in_jupyter = True
+        
     @staticmethod
     def interruption_handler(
         signum: Union[
@@ -937,12 +944,9 @@ class Scalene:
         f = frame
         try:
             while "<" in Filename(f.f_code.co_name):
-                f = cast(FrameType, frame.f_back)
-                if (
-                    "<genexpr>" in f.f_code.co_name
-                    or "<module>" in f.f_code.co_name
-                    or "<listcomp>" in f.f_code.co_name
-                ):
+                f = cast(FrameType, f.f_back)
+                # Handle case where the function with the name wrapped in triangle brackets is at the bottom of the stack
+                if f is None:
                     return
         except:
             return
@@ -1058,7 +1062,7 @@ class Scalene:
                     # Check if pointer actually matches
                     if stats.last_malloc_triggered[2] == pointer:
                         freed_last_trigger += 1
-            stats.memory_footprint_samples.add(stats.current_footprint)
+            stats.memory_footprint_samples.append([time.monotonic_ns() - Scalene.__start_time, stats.current_footprint])
         after = stats.current_footprint
 
         if freed_last_trigger:
@@ -1151,7 +1155,7 @@ class Scalene:
                     0, stats.memory_current_footprint[fname][lineno]
                 )
 
-            stats.per_line_footprint_samples[fname][lineno].add(curr)
+            stats.per_line_footprint_samples[fname][lineno].append([time.monotonic_ns() - Scalene.__start_time, curr])
             # If we allocated anything, then mark this as the last triggering malloc
             if allocs > 0:
                 last_malloc = (
@@ -1316,6 +1320,7 @@ class Scalene:
             sys.exit(1)
         Scalene.__stats.start_clock()
         Scalene.enable_signals()
+        Scalene.__start_time = time.monotonic_ns()
         Scalene.__done = False
 
     @staticmethod
@@ -1324,6 +1329,22 @@ class Scalene:
         Scalene.__done = True
         Scalene.disable_signals()
         Scalene.__stats.stop_clock()
+        if Scalene.__args.web and not Scalene.__args.cli and not Scalene.__in_jupyter:
+            import webbrowser
+            try:
+                if not webbrowser.get():
+                    # Could not open a web browser tab;
+                    # act as if --web was not specified.
+                    Scalene.__args.web = False
+                else:
+                    # Force JSON output to profile.json.
+                    Scalene.__args.json = True
+                    Scalene.__output.json = True
+                    Scalene.__output.html = False
+                    Scalene.__output.output_file = 'profile.json'
+            except:
+                # Couldn't find a browser.
+                Scalene.__args.web = False
 
     @staticmethod
     def is_done() -> bool:
@@ -1419,6 +1440,37 @@ class Scalene:
                 print(
                     "Scalene: Program did not run for long enough to profile."
                 )
+            if Scalene.__args.web and not Scalene.__args.cli and not Scalene.__in_jupyter:
+                # Start up a web server (in a background thread) to host the GUI,
+                # and open a browser tab to the server.
+                import http.server
+                import socketserver
+                import webbrowser
+                PORT = 8088
+
+                # Silence web server output by overriding logging messages.
+                class NoLogs(http.server.SimpleHTTPRequestHandler):
+                    def log_message(self, format, *args):
+                        return
+                    def log_request(code, size):
+                        return
+                Handler = NoLogs
+                with socketserver.TCPServer(("", PORT), Handler) as httpd:
+                    import threading
+                    t = threading.Thread(target=lambda: httpd.serve_forever())
+                    # Copy files into a new directory and then point the tab there.
+                    import shutil
+                    webgui_dir = pathlib.Path(
+                        tempfile.mkdtemp(prefix="scalene-gui")
+                    )
+                    shutil.copytree(os.path.join(os.path.dirname(__file__), 'scalene-gui'),
+                                    os.path.join(webgui_dir, 'scalene-gui'))
+                    shutil.copy("profile.json", os.path.join(webgui_dir, 'scalene-gui'))
+                    os.chdir(os.path.join(webgui_dir, 'scalene-gui'))
+                    t.start()
+                    webbrowser.open_new_tab(f"http://localhost:{PORT}/profiler.html")
+                    t.join()
+                
         return exit_status
 
     @staticmethod
@@ -1432,7 +1484,7 @@ class Scalene:
         Scalene.__is_child = args.pid != 0
         # the pid of the primary profiler
         Scalene.__parent_pid = args.pid if Scalene.__is_child else os.getpid()
-
+            
     @staticmethod
     def set_initialized() -> None:
         Scalene.__initialized = True
